---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Add an example of code that produces the problem you're reporting.
We should be able to copy your code, run it and get the same result.

**Expected behavior**
A clear and concise description of what you expected to happen.

**System information:**
 - OS: [e.g. MacOS]
 - Node.js version [e.g. 14.7]

**Additional context**
Add any other context about the problem here.
